@@ -17,6 +17,7 @@ use crate::style::{
     CellStyle, ColStyle, FontFaceDecl, GraphicStyle, HeaderFooter, MasterPage, PageStyle,
     ParagraphStyle, RowStyle, StyleOrigin, StyleUse, TableStyle, TextStyle,
 };
+use crate::validation::ValidationDisplay;
 use crate::xmltree::{XmlContent, XmlTag};
 use crate::{ucell, Length, SCell, Sheet, Value, ValueFormat, ValueType, Visibility, WorkBook};
 
@@ -829,13 +830,14 @@ fn write_ods_content(book: &WorkBook, zip_out: &mut OdsWriter) -> Result<(), Ods
             tag.name() == "text:dde-connection-decls" ||
             // tag.name() == "text:alphabetical-index-auto-mark-file" ||
             tag.name() == "table:calculation-settings" ||
-            tag.name() == "table:content-validations" ||
             tag.name() == "table:label-ranges"
         {
             write_xmltag(tag, &mut xml_out)?;
         }
     }
 
+    write_content_validations(&book, &mut xml_out)?;
+
     for sheet in &book.sheets {
         write_sheet(&book, sheet, &mut xml_out)?;
     }
@@ -861,6 +863,72 @@ fn write_ods_content(book: &WorkBook, zip_out: &mut OdsWriter) -> Result<(), Ods
     Ok(())
 }
 
+fn write_content_validations(book: &WorkBook, xml_out: &mut XmlOdsWriter) -> Result<(), OdsError> {
+    xml_out.elem("table:content-validations")?;
+
+    for valid in book.validations.values() {
+        xml_out.elem("table:content-validation")?;
+        xml_out.attr_esc("table:name", valid.name())?;
+        let mut cond = "of:".to_string();
+        cond.push_str(valid.condition());
+        xml_out.attr_esc("table:condition", cond.as_str())?;
+        xml_out.attr(
+            "table:allow-empty-cell",
+            if valid.allow_empty() { "true" } else { "false" },
+        )?;
+        xml_out.attr(
+            "table:display-list",
+            match valid.display() {
+                ValidationDisplay::NoDisplay => "no",
+                ValidationDisplay::Unsorted => "unsorted",
+                ValidationDisplay::SortAscending => "sort-ascending",
+            },
+        )?;
+        xml_out.attr_esc("table:base-cell-address", &valid.base_cell().to_string())?;
+
+        if let Some(err) = valid.err() {
+            if err.text().is_some() {
+                xml_out.elem("table:error-message")?;
+            } else {
+                xml_out.empty("table:error-message")?;
+            }
+            xml_out.attr("table:display", err.display().to_string())?;
+            xml_out.attr("table:message-type", err.msg_type().to_string())?;
+            if let Some(title) = err.title() {
+                xml_out.attr("table:title", title)?;
+            }
+            if let Some(text) = err.text() {
+                write_xmltag(text, xml_out)?;
+            }
+            if err.text().is_some() {
+                xml_out.end_elem("table:error-message")?;
+            }
+        }
+        if let Some(err) = valid.help() {
+            if err.text().is_some() {
+                xml_out.elem("table:help-message")?;
+            } else {
+                xml_out.empty("table:help-message")?;
+            }
+            xml_out.attr("table:display", err.display().to_string())?;
+            if let Some(title) = err.title() {
+                xml_out.attr("table:title", title)?;
+            }
+            if let Some(text) = err.text() {
+                write_xmltag(text, xml_out)?;
+            }
+            if err.text().is_some() {
+                xml_out.end_elem("table:help-message")?;
+            }
+        }
+
+        xml_out.end_elem("table:content-validation")?;
+    }
+    xml_out.end_elem("table:content-validations")?;
+
+    Ok(())
+}
+
 /// Is the cell hidden, and if yes how many more columns are hit.
 fn check_hidden(ranges: &[CellRange], row: ucell, col: ucell) -> (bool, ucell) {
     if let Some(found) = ranges.iter().find(|s| s.contains(row, col)) {
@@ -1314,6 +1382,9 @@ fn write_cell(
     } else if let Some(style) = book.def_style(cell.value.value_type()) {
         xml_out.attr_esc("table:style-name", style.as_str())?;
     }
+    if let Some(validation) = &cell.validation {
+        xml_out.attr("table:content-validation-name", validation.as_str())?;
+    }
 
     // Spans
     if cell.span.0 > 1 {
