@@ -2,7 +2,7 @@ use color::Rgb;
 
 use spreadsheet_ods::style::units::Length;
 use spreadsheet_ods::style::{MasterPage, PageStyle, TableStyle};
-use spreadsheet_ods::{cm, read_ods, write_ods, OdsError, WorkBook};
+use spreadsheet_ods::{cm, read_ods, write_ods, OdsError, Sheet, WorkBook};
 
 #[test]
 fn test_pagelayout() -> Result<(), OdsError> {
@@ -53,6 +53,8 @@ fn test_crpagelayout() -> Result<(), OdsError> {
     ts.set_master_page_name(&mp);
     let _ts = wb.add_tablestyle(ts);
 
+    wb.push_sheet(Sheet::new());
+
     write_ods(&mut wb, "test_out/hf0.ods")?;
 
     Ok(())
